@@ -1,7 +1,8 @@
 package Grizzly;
+
 # ABSTRACT: Grizzly - A command-line interface for looking up stock quote.
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 use strict;
 use warnings;
@@ -9,15 +10,19 @@ use warnings;
 use App::Cmd::Setup -app;
 1;
 
-=encoding utf8
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Grizzly - A command-line interface for looking up stock quote.
+Grizzly - Grizzly - A command-line interface for looking up stock quote.
 
-=head1 DESCRIPTION
+=head1 VERSION
 
-Grizzly will output the stock quote of the given symbol.
+version 0.102
 
 =head1 SYNOPSIS
 
@@ -43,7 +48,21 @@ help - Displays a help message on how to use Grizzly.
 
 version - Displays Grizzly's version number.
 
-=head1 API Key
+=head1 DESCRIPTION
+
+Grizzly will output the stock quote of the given symbol.
+
+=head1 NAME
+
+Grizzly - A command-line interface for looking up stock quote.
+
+=head1 Setup
+
+=head2 Installation
+
+    cpanm Grizzly
+
+=head2 API Key
 
 You will need to get a free API key from L<NewsAPI|https://newsapi.org/>. Afterwards you will need to set the NEWS_API_KEY environment variable to the API key.
 
@@ -56,4 +75,17 @@ Nobunaga <nobunaga@cpan.org>
 This software is copyright (c) 2021 by Nobunaga.
 
 MIT License
- 
\ No newline at end of file
+
+=head1 AUTHOR
+
+Nobunaga <nobunaga@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2021 by Nobunaga.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
